@@ -1,10 +1,10 @@
 import numpy as np
 import pandas as pd
 import sspa.utils as utils
-import rpy2.robjects as ro
-from rpy2.robjects.packages import importr
-from rpy2.robjects import pandas2ri
-from rpy2.robjects.conversion import localconverter
+# import rpy2.robjects as ro
+# from rpy2.robjects.packages import importr
+# from rpy2.robjects import pandas2ri
+# from rpy2.robjects.conversion import localconverter
 
 # for rpy2
 base = importr('base')
@@ -28,6 +28,10 @@ def sspa_fgsea(mat, metadata, pathway_df, min_entity=2):
 
     # Get rankings - SNR
     mat['Target'] = pd.factorize(metadata)[0]
+    # Check user has only input two classes of samples 
+    if len(set(mat['Target'].tolist())) > 2:
+        raise ValueError('More than two metadata classes detected. Only two metadata classes are supported in GSEA.')
+
     class_a = mat.loc[mat["Target"] == 0]
     class_a.drop(['Target'], axis=1, inplace=True)
     class_b = mat.loc[mat["Target"] != 0]
