@@ -1,9 +1,9 @@
 import pandas as pd
 import sspa.utils as utils
-import rpy2.robjects as ro
-from rpy2.robjects.packages import importr
-from rpy2.robjects import pandas2ri
-from rpy2.robjects.conversion import localconverter
+# import rpy2.robjects as ro
+# from rpy2.robjects.packages import importr
+# from rpy2.robjects import pandas2ri
+# from rpy2.robjects.conversion import localconverter
 
 # for rpy2
 base = importr('base')
